@@ -1,6 +1,8 @@
 from datetime import datetime, timezone
 from typing import Union
 
+from .validate import validate_max_tokens, validate_replenish_time
+
 
 class TokenBucket:
     def __init__(self, replenish_time: int, max_tokens: int) -> None:
@@ -10,13 +12,8 @@ class TokenBucket:
         self.last_replenished: float = datetime.now(timezone.utc).timestamp()
         self.identifier: Union[str, None] = None
         self.cost: int = 0
-        self._validate_init()
-
-    def _validate_init(self) -> None:
-        if not isinstance(self.replenish_time, int):
-            raise TypeError("Invalid `replenish_time` type")
-        if not isinstance(self.max_tokens, int):
-            raise TypeError("Invalid `max_tokens` type")
+        validate_max_tokens(self.max_tokens)
+        validate_replenish_time(self.replenish_time)
 
     def consume(self) -> bool:
         if self.tokens < self.cost:
